==> signer-1.101.0-sources.jar: software/amazon/awscdk/services/signer/Platform.java <==
package software.amazon.awscdk.services.signer;

/**
 * Platforms that are allowed with signing config.
 * <p>
 * @see https://docs.aws.amazon.com/signer/latest/developerguide/gs-platform.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-28T11:07:19.630Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.signer.$Module.class, fqn = "@aws-cdk/aws-signer.Platform")
public class Platform extends software.amazon.jsii.JsiiObject {

    protected Platform(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Platform(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        AMAZON_FREE_RTOS_DEFAULT = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.signer.Platform.class, "AMAZON_FREE_RTOS_DEFAULT", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.signer.Platform.class));
        AMAZON_FREE_RTOS_TI_CC3220_SF = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.signer.Platform.class, "AMAZON_FREE_RTOS_TI_CC3220SF", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.signer.Platform.class));
        AWS_IOT_DEVICE_MANAGEMENT_SHA256_ECDSA = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.signer.Platform.class, "AWS_IOT_DEVICE_MANAGEMENT_SHA256_ECDSA", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.signer.Platform.class));
        AWS_LAMBDA_SHA384_ECDSA = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.signer.Platform.class, "AWS_LAMBDA_SHA384_ECDSA", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.signer.Platform.class));
    }

    /**
     * Specification of signature format and signing algorithms with SHA256 hash and ECDSA encryption for Amazon FreeRTOS.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.signer.Platform AMAZON_FREE_RTOS_DEFAULT;

    /**
     * Specification of signature format and signing algorithms with SHA1 hash and RSA encryption for Amazon FreeRTOS.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.signer.Platform AMAZON_FREE_RTOS_TI_CC3220_SF;

    /**
     * Specification of signature format and signing algorithms for AWS IoT Device.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.signer.Platform AWS_IOT_DEVICE_MANAGEMENT_SHA256_ECDSA;

    /**
     * Specification of signature format and signing algorithms for AWS Lambda.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.signer.Platform AWS_LAMBDA_SHA384_ECDSA;

    /**
     * The id of signing platform.
     * <p>
     * @see https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-signer-signingprofile.html#cfn-signer-signingprofile-platformid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getPlatformId() {
        return software.amazon.jsii.Kernel.get(this, "platformId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}

==> signer-1.174.0-sources.jar: software/amazon/awscdk/services/signer/Platform.java <==
package software.amazon.awscdk.services.signer;

/**
 * Platforms that are allowed with signing config.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * SigningProfile signingProfile = SigningProfile.Builder.create(this, "SigningProfile")
 *         .platform(Platform.AWS_LAMBDA_SHA384_ECDSA)
 *         .build();
 * </pre></blockquote>
 * <p>
 * @see <a href="https://docs.aws.amazon.com/signer/latest/developerguide/gs-platform.html">https://docs.aws.amazon.com/signer/latest/developerguide/gs-platform.html</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-21T22:31:00.802Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.signer.$Module.class, fqn = "@aws-cdk/aws-signer.Platform")
public class Platform extends software.amazon.jsii.JsiiObject {

    protected Platform(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Platform(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        AMAZON_FREE_RTOS_DEFAULT = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.signer.Platform.class, "AMAZON_FREE_RTOS_DEFAULT", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.signer.Platform.class));
        AMAZON_FREE_RTOS_TI_CC3220_SF = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.signer.Platform.class, "AMAZON_FREE_RTOS_TI_CC3220SF", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.signer.Platform.class));
        AWS_IOT_DEVICE_MANAGEMENT_SHA256_ECDSA = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.signer.Platform.class, "AWS_IOT_DEVICE_MANAGEMENT_SHA256_ECDSA", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.signer.Platform.class));
        AWS_LAMBDA_SHA384_ECDSA = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.signer.Platform.class, "AWS_LAMBDA_SHA384_ECDSA", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.signer.Platform.class));
    }

    /**
     * Specification of signature format and signing algorithms with SHA256 hash and ECDSA encryption for Amazon FreeRTOS.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.signer.Platform AMAZON_FREE_RTOS_DEFAULT;

    /**
     * Specification of signature format and signing algorithms with SHA1 hash and RSA encryption for Amazon FreeRTOS.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.signer.Platform AMAZON_FREE_RTOS_TI_CC3220_SF;

    /**
     * Specification of signature format and signing algorithms for AWS IoT Device.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.signer.Platform AWS_IOT_DEVICE_MANAGEMENT_SHA256_ECDSA;

    /**
     * Specification of signature format and signing algorithms for AWS Lambda.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.signer.Platform AWS_LAMBDA_SHA384_ECDSA;

    /**
     * The id of signing platform.
     * <p>
     * @see <a href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-signer-signingprofile.html#cfn-signer-signingprofile-platformid">https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-signer-signingprofile.html#cfn-signer-signingprofile-platformid</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getPlatformId() {
        return software.amazon.jsii.Kernel.get(this, "platformId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}
